@@ -1,6 +1,6 @@
 """Simple transparent wrapper for a small portion of Pika. It has a nice interface."""
 
-__version__ = '0.0.4'
+__version__ = '0.0.5'
 
 import logging
 import pickle
@@ -21,14 +21,21 @@ Errors = (
 class Queue:
     max_priority = 10
     
-    def __init__(self, name, username='guest', password='guest', **conn_params):
+    def __init__(self, name, host='localhost', port=5672, username='guest', password='guest', max_retries=100, retry_interval=5):
         name = str(name).strip()
         assert len(name) < 200, f'Queue name too long: {name!r}'
 
         self.queue = f'bunnymq.{name}'
-        
+
+        self.host = host
+        self.port = port
         self.credentials = pika.PlainCredentials(username, password)
-        self.conn_params = conn_params
+
+        self.max_retries = int(max_retries)
+        assert self.max_retries > 0, f'max retries should be > 0, given {self.max_retries!r} times'
+
+        self.retry_interval = int(retry_interval)
+        assert self.retry_interval > 0, f'retry interval should be > 0, given {self.retry_interval!r} sec'
         
         self.setup()
         
@@ -52,7 +59,7 @@ class Queue:
     def _setup(self):
         self.disconnect()
 
-        self.connection = pika.BlockingConnection(pika.ConnectionParameters(credentials=self.credentials, **self.conn_params))                                                
+        self.connection = pika.BlockingConnection(pika.ConnectionParameters(credentials=self.credentials, host=self.host, port=self.port))                                                
         self.channel = self.connection.channel()
 
         self._declare_queue()
@@ -61,12 +68,14 @@ class Queue:
         self.stream = self.channel.consume(self.queue)
 
     def setup(self):
-        while True:
+        for _ in range(self.max_retries):
             try:
                 return self._setup()
             except Errors as e:
                 log.error(f'{e}, retrying in 2 secs.')
-                time.sleep(2)
+                time.sleep(self.retry_interval)
+
+        raise Exception('Max retries exceeded.')
         
     def _put(self, msg, priority):
         self.channel.basic_publish(
@@ -79,15 +88,13 @@ class Queue:
     def put(self, msg, priority=5):
         assert 0 < int(priority) <  self.max_priority
 
-        func = lambda: self._put(msg, priority=priority)
-        
         try:
-            return func()
+            return self._put(msg, priority=priority)
         except Errors as e:
             log.debug(e)
         
         self.setup()
-        func()
+        self._put(msg, priority=priority)
 
     def requeue(self):
         try:
